import { DevServerContext } from '../../types/devServer.js';
import { Connection } from './connection.js';
import type { HMR_Data } from '@lwc/lwc-dev-server-types';
import type { TransformOptions } from '@lwc/compiler';
/**
 * Class representing a client that has connected to the dev server.
 * This class represents a client that is connected and ready to receive hot module updates.
 * After the hmr-client is connected, all communication between itself and lwc-dev-server are handled
 * by this class.
 */
export declare class Client {
    clientId: string;
    url: string;
    activePaths: Map<string, TransformOptions>;
    connection: Connection;
    ctx: DevServerContext;
    constructor(clientId: string, url: string, connection: Connection, ctx: DevServerContext);
    onClose(callback: () => void): void;
    addActivePaths(paths: {
        modulePath: string;
        compileOptions: TransformOptions;
    }[]): void;
    removeStalePaths(paths: string[]): void;
    getCompileOptions(path: string): TransformOptions | undefined;
    send(data: HMR_Data): void;
    messageCallback(data: HMR_Data): Promise<void>;
    close(): void;
}
